@@ -34,16 +34,17 @@ def pypi_update():
         pk = listPakeages[i].split(' ')[0]
         show_updatePk.append(pk)
         print(i - 1, '、', pk)
-
-    print('输入序号可以更新单个包\n输入0更新全部\n输入-x为过滤第x项(x为前置的序号)\n输入任意非数字退出程序')
     while True:
         try:
+            print('输入序号可以更新单个包\n输入0更新全部\n输入-x为过滤第x项(x为前置的序号)\n输入任意非数字退出程序')
             userOrder = input('请输入需要的操作：')
             print('')
             if int(userOrder) == 0:
                 if useMirror == '':
                     for pakeage in show_updatePk:
                         subprocess.call('pip install --upgrade ' + pakeage, shell=True)
+                        # msg = os.popen('pip install --upgrade ' + pakeage)
+
                 else:
                     for pakeage in show_updatePk:
                         subprocess.call('pip install --upgrade ' + pakeage + ' -i '+useMirror, shell=True)
@@ -54,28 +55,40 @@ def pypi_update():
                 try:
                     if useMirror == '':
                         subprocess.call('pip install --upgrade ' + show_updatePk[int(userOrder) - 1], shell=True)
+                        # msg = os.popen('pip install --upgrade ' + show_updatePk[int(userOrder) - 1])
                     else:
                         subprocess.call('pip install --upgrade ' + show_updatePk[int(userOrder) - 1] + ' -i ' + useMirror, shell=True)
+                        # msg = os.popen('pip install --upgrade ' + show_updatePk[int(userOrder) - 1] + ' -i ' + useMirror)
+                    # msglsit = [x.lower for x in list(msg)]
+                    # for i in msglsit:
+                    #     if 'error' in i:
+                    #         print(show_updatePk[int(userOrder) - 1], '包含ERROR信息，可能未更新成功')
                     print('已操作：', show_updatePk[int(userOrder)-1])
-                    print('更新数据：')
+                    del show_updatePk[int(userOrder)-1]
+                    print('未操作数据：')
                     for pIndex, p in enumerate(show_updatePk):
                         print(pIndex+1, '、', p)
                 except:
+                    for pakeIndex, pakeage in enumerate(show_updatePk):
+                        print(pakeIndex+1, '、', pakeage)
                     print('输入的数字有误，可能没有此序号')
             elif int(userOrder) < 0:
                 try:
                     removeList = userOrder.split('-')[1]
                     pakeNum = int(removeList)
                     del show_updatePk[pakeNum-1]
-                    print('更新数据：')
+                    clearConsole()
+                    print('未操作数据：')
                     for pakeIndex, pakeage in enumerate(show_updatePk):
                         print(pakeIndex+1, '、', pakeage)
                 except:
-                    print('输入的序号有误或者符号错误')
+                    for pakeIndex, pakeage in enumerate(show_updatePk):
+                        print(pakeIndex+1, '、', pakeage)
+                    print('输入的数字有误，可能没有此序号')
         except:
             print('取消更新')
             clearConsole()
             break
 
-# if __name__ == '__main__':
-#     pypi_update()
\ No newline at end of file
+if __name__ == '__main__':
+    pypi_update()
\ No newline at end of file
