@@ -8,11 +8,15 @@ def pypi_upload():
         try:
             control_type = input('1、生成配置文件结构\n2、打包程序\n3、上传程序\n0、退出程序\n请通过序号选择需要的操作：')
             if int(control_type) == 1:
-                changepath = input('一般这种文件都会放在根目录中,程序默认使用上一级目录进行创建，是否手动指定根目录？Y为重新指定，其他任意字符为不指定：')
+                changepath = input('一般这种文件都会放在根目录中,程序默认使用当前目录进行创建，是否手动指定根目录？Y为重新指定，其他任意字符为不指定：')
                 if changepath.lower() == 'y':
-                    filepath = input('请输入文件路径：')+'/'
+                    filepath = input('请输入文件路径：')
+                    if filepath[-1] in ('/', '\\'):
+                        pass
+                    else:
+                        filepath = filepath + '/'
                 else:
-                    filepath = '../'
+                    filepath = './'
                 mkfileList = ['setup.py', 'LICENSE.txt', 'README.md']
                 for filename in mkfileList:
                     Path(filepath+filename).touch(exist_ok=True)
@@ -23,7 +27,7 @@ with open("README.md", "r", encoding='utf-8') as fh:
     long_description = fh.read()
 setuptools.setup(
     name="xxx",    # 包名
-    version="0.1",  # 版本
+    version="0.0.1",  # 版本
     author="hzz",   # 作者
     author_email="1538379200@qq.com",    # 邮箱
     description="项目介绍",
@@ -31,9 +35,9 @@ setuptools.setup(
     long_description_content_type="text/markdown",  # 使用介绍文本
     url="",     # github等项目地址
     packages=setuptools.find_packages(),    # 自动查找包，手动写也可
-    install_requires=['setuptools>=60.8.1', 'wheel>=0.37.1', 'twine>=3.8.0'],    # 安装此包所需的依赖
+    install_requires=['setuptools>=60.8.1', 'wheel>=0.37.1', 'twine>=3.8.0'],    # 安装此包所需的依赖，没有为空
     entry_points={
-        'console_scripts': [        # 命令行运行代码
+        'console_scripts': [        # 命令行运行代码,如不需要，可以把entry_points这段删除
             'pypi-up=pypk.main:run'
         ],
     },
@@ -70,18 +74,18 @@ SOFTWARE.''')
                         pass
                 print('文件创建完成，请修改配置项和开源协议等')
             elif int(control_type) == 2:
-                basepath = input('指定程序根目录,不输入则默认上一级目录：')
+                basepath = input('指定程序根目录,不输入则默认当前目录：')
                 print('正在打包文件……')
                 if ':' in basepath:
                     sdisk = basepath.split(':')[0]
                     os.system(f'cd {sdisk}: && cd {basepath} &&　python setup.py sdist bdist_wheel')
                 elif basepath == '':
-                    os.system('cd .. && python setup.py sdist bdist_wheel')
+                    os.system('python setup.py sdist bdist_wheel')
                 else:
-                    os.system(f'cd {basepath} && python setup.py sdist bdist_wheel')
+                    os.system('python setup.py sdist bdist_wheel')
                 print('文件打包操作已完成')
             elif int(control_type) == 3:
-                workpath = input('请输入当前文件根目录,不输入则默认上一级目录：')
+                workpath = input('请输入当前文件根目录,不输入则默认当前目录：')
                 username = input('请输入用户名：')
                 password = input('请输入密码：')
                 print('准备进行文件上传')
@@ -89,7 +93,7 @@ SOFTWARE.''')
                     sdisk = workpath.split(':')[0]
                     os.system(f'cd {sdisk}: && cd {workpath} && py -m twine upload -u {username} -p {password}  dist/*')
                 elif workpath == '':
-                    os.system(f'cd .. && py -m twine upload -u {username} -p {password}  dist/*')
+                    os.system(f'py -m twine upload -u {username} -p {password}  dist/*')
                 else:
                     os.system(f'cd {workpath} && py -m twine upload -u {username} -p {password}  dist/*')
                 print('已完成文件上传程序')
